# Wrappity usage guide

## Wrapping and unwrapping

## The Wrapper class and getting the actual wrapped value

## Ensuring lists

## How to handle Python-incompatible attributes

## Access misses - getting to know
